@@ -46,6 +46,8 @@ class MPTTOptions(object):
             )
 
         for key, value in opts:
+            if key.startswith('__'):
+                continue
             setattr(self, key, value)
 
         # Normalize order_insertion_by to a list
@@ -297,7 +299,11 @@ class MPTTModelBase(ModelBase):
                 # for backwards compatibility, add .tree too (or whatever's in tree_manager_attr)
                 tree_manager_attr = cls._mptt_meta.tree_manager_attr
                 if tree_manager_attr != 'objects':
-                    another = getattr(cls, tree_manager_attr, None)
+                    # Don't trigger the DepricationWarning by our-self
+                    # another = getattr(cls, tree_manager_attr, None)
+                    another = reduce(lambda acc, sup: acc or \
+                                     sup.__dict__.get(tree_manager_attr, None),
+                                     cls.__mro__, None)
                     if another is None:
                         # wrap with a warning on first use
                         from django.db.models.manager import ManagerDescriptor
@@ -477,7 +483,7 @@ class MPTTModel(models.Model):
             )
         else:
             qs = self._tree_manager._mptt_filter(qs,
-                parent__id=getattr(self, '%s_id' % self._mptt_meta.parent_attr),
+                parent__pk=getattr(self, '%s_id' % self._mptt_meta.parent_attr),
                 left__gt=self._mpttfield('right'),
             )
 
@@ -499,7 +505,7 @@ class MPTTModel(models.Model):
             qs = qs.order_by('-%s' % opts.tree_id_attr)
         else:
             qs = self._tree_manager._mptt_filter(qs,
-                parent__id=getattr(self, '%s_id' % opts.parent_attr),
+                parent__pk=getattr(self, '%s_id' % opts.parent_attr),
                 right__lt=self._mpttfield('left'),
             )
             qs = qs.order_by('-%s' % opts.right_attr)
@@ -532,7 +538,7 @@ class MPTTModel(models.Model):
             queryset = self._tree_manager._mptt_filter(parent__isnull=True)
         else:
             parent_id = getattr(self, '%s_id' % self._mptt_meta.parent_attr)
-            queryset = self._tree_manager._mptt_filter(parent__id=parent_id)
+            queryset = self._tree_manager._mptt_filter(parent__pk=parent_id)
         if not include_self:
             queryset = queryset.exclude(pk=self.pk)
         return queryset
